/*------------------------------------------------------------------------------
 *
 *  English Text-to-Speech Installer: 
 *				Installation of English Text-to-Speech software
 *
 *				Copyright  1994 Apple Computer, Inc.
 *				All rights reserved.
 *
 *	File:		TTS_English_14_Install.r -	Rez Source
 *
 *	Author:		Deric Horn
 *
 *	History:	<1>	(11/8/94) Created this file.
 *				Many updates by Tim Fredenburg.
 *
 *	Build:		
 *				Make -f 'Installer Script.make' 'TTS Installer Script'
 *
 *----------------------------------------------------------------------------*/

// NOTES:
//
// We don't have a separate entries to delete old versions of files that
// had a different creator because the Installer can't deal with two
// different file specs that only differ in the creator (it was refusing to
// install over an existing file, or deleting the file and not installing a
// new version).  Examples: MacinTalk 2 used to have a creator of 'ttsc'
// and now has creator 'mtk2'.  Similarly, MacinTalk 3 and its voices used
// to have creator 'ttsc' and now have 'mtk3'.  So we think of the old creator
// files as just old versions of the current files and they get updated or deleted
// by the entry for the current file having the TypeCrNeedNotMatch flag set.



#include	"InstallerTypes.r"
include		"EnglishTTS.rsrc";								/* vers and splash resources */


	// Assertions.  Must all have unique values.
	
#define aBootableVolume			1		// Chosen volume can be booted from.
#define aNoSystem				2		// Chosen volume is not bootable.
#define aSystem7				3		// Chosen volume has System 7.0 or later installed.
#define aSystem6Usable			4		// Chosen volume has speech-usable version of System 6.
#define aSystemTooEarly			5		// Chosen volume has a System version too old for speech.


//	Definition for the user function	//	Gestalt user functions
#define	chkGr33MHz					1001
include "GestaltFxns.rsrc" 'infn' (1001)  as 'infn' (chkGr33MHz);

#if	(Debug)
	include		"Installer Debugger.rsrc" NOT 'vers';
#endif

/* Date is the current release date put in 'icmt' rsrc. ScriptCheck will convert  */
#define currentReleaseDate			4301995					/* Official release date */
#define kTTSVersion					"1.4"	 				/* Version */
#define kTTSVersionIcmt				140	 					/* Version goes in the 'icmt' rsrc */

/* CONSTANTS: put a 1 in the creation date field of source 'infs' to have ScriptCheck set date */
#define kScriptCheckSetsDate		0x01
#define kMinMemMB					04						/* memory needed to install (UPDATE Error Message if changed!)*/

/* RULE: Definitions for the rule */
#define rlCheck_DiskSpace_SysExists	1000
#define rlBootDiskError				1001
#define rlCheck_040					1002
#define rlCheck_Fast030				1003
#define rlCheck_Sys607				1004
#define rlOther_Sys7				1005
#define rlCheck_PPC					1006
#define rlBootableVolume			1007
#define rlNoSystem					1008
#define rlSystem7					1009
#define rlSystem6Usable				1010
#define rlSystemTooEarly			1011
#define rlCheckUsableSystem			1012
#define rlSystemVersionError		1013
#define rlCustomCheck607			1014
#define rlCustomCheckSys7			1015
#define rlCustomSystemVersionError	1016

#define diskOrder					1000					/* for indo resource */

#define sourceFileBase				3000
#define targetFileBase				4000
#define actionAtomBase				sourceFileBase
#define	fsTargetSystem				5000
#define	fsTargetFinder				5001

/* PACKAGES: Definition of the packages. */
#define pkInstallEnglishTTS				3000
#define pkInstallMacinTalk2				3001
#define pkInstallMacinTalk3				3002
#define pkInstallMacinTalkPro			3003
#define pkInstallSpeechMgrCustom		3004
#define pkRemoveMacinTalk2				3005
#define pkRemoveMacinTalk3				3006
#define pkRemoveMacinTalkPro			3007
#define pkInstallMacinTalk2_607			3009
#define pkInstallSpeechCDevCustom		3010
#define pkInstallSpeechMgrExtCustom		3011
#define pkInstallSpeechMgr607Custom		3012
#define pkRemoveMisplacedMacinTalk2		3013
#define pkRemoveOldMacinTalk2			3014
#define pkRemoveMisplacedMacinTalk3		3015
#define pkRemoveMisplacedMacinTalkPro	3016
#define pkRemoveOldMacinTalkPro			3017

/* COMMENT: Definition for the package comment resource */
#define cmtIEnglishTTS				pkInstallEnglishTTS
#define cmtIMacinTalk2				pkInstallMacinTalk2
#define cmtIMacinTalk3				pkInstallMacinTalk3
#define cmtIMacinTalkPro			pkInstallMacinTalkPro
#define cmtISpeechMgr				pkInstallSpeechMgrCustom
#define cmtISpeechCDev				pkInstallSpeechCDevCustom
#define cmtISpeechMgrExt			pkInstallSpeechMgrExtCustom

#define iconEnglishTTS				pkInstallEnglishTTS
#define iconMacinTalk2				pkInstallMacinTalk2
#define iconMacinTalk3				pkInstallMacinTalk3
#define iconMacinTalkPro			pkInstallMacinTalkPro
#define iconSpeechMgr				pkInstallSpeechMgrCustom
#define iconSpeechCDev				pkInstallSpeechCDevCustom
#define iconSpeechMgrExt			pkInstallSpeechMgrExtCustom

/* SOURCE DISK: This is the name of the source disks */
#define ProgramDisk1				"English TTS 1:"
#define ProgramDisk2				"English TTS 2:"
#define ProgramDisk3				"English TTS 3:"
#define ProgramDisk4				"English TTS 4:"
#define ProgramDisk5				"English TTS 5:"

// File ID's
// These need to be added to sourceFileBase or targetFileBase to get the full ID.
// This script was written without using definitions for file ID's so there aren't
// very many of them #defined yet.

// ID's 1-2 are used.
#define fSpeechCDev					3
#define fSpeechMgr					4
#define fMT2ExtFolder				5
// ID's 6-7 are used.
#define fSpeechCDevNoRemove			33
#define fSpeechMgrNoRemove			34
// ID's 50-87 are used.
// ID's 100-101 are used.
// ID's 200-210 are used.
#define fDelOldMTVoicesSysFolder	212
#define fDelOldMT2VoicesSysFolder	213
#define fDelMT2ExtFolder			214
#define fDelMT2SysFolder			215
#define fDelMT3SysFolder			216
#define fDelMTPSysFolder			217
// ID's 250-331 are used.
// ID's 350-369 are used.
// ID 400 is used.


/***************************** Preferences Resource *****************************************/

// The only reason we need a preferences resource is to specify the help pages.  We use
// the defaults for all other fields.

resource 'inpr' ( 300 )						// Required resource ID.
{
	format0
	{
		useDiskTargetMode,					// Since always install in System Folder.
		dontAllowUserToSetSystemDisk,		// Meaningless in Disk Target mode.
		showSelectedSizeInCustom,			// Might be some help.
		noSetupFunctionSupplied,			// None for now.
		dontAllowCleanInstall,				// Not documented but sounds dangerous.
		dontAllowServerAsTarget,			// Unsupported and totally dangerous.
		
		'', 0,								// No Setup Function.
		
		{
			401, 421, 401, 421,				// Help PICT resource ID's, page 1.
			402, 422, 402, 422,				// Help PICT resource ID's, page 2.
			403, 423, 403, 423,				// Help PICT resource ID's, page 3.
			404, 424, 404, 424,				// Help PICT resource ID's, page 4.
			405, 425, 405, 425,				// Help PICT resource ID's, page 5.
		},
		
		""									// Recommended folder name; not used.
	}
};

/***************************** indo Resource ************************************************/
resource 'indo' (DiskOrder) {
	format0 {{
		ProgramDisk1,
		ProgramDisk2,
		ProgramDisk3,
		ProgramDisk4,
		ProgramDisk5,
	}};
};


/*********************************** Global Rules ********************************************/
//
// Currently, the global rules only set assertions.

resource 'infr' ( kGlobalFrameworkRsrcID )					/* Rule Framework */
{
	format0
	{{
			// Determine whether the chosen volume can be a boot volume.
			
		pickFirst,
		{
			rlBootableVolume,
			rlNoSystem
		},
		
		
			// Determine which version of the OS is installed on the chosen volume.
			
		pickFirst,
		{
			rlSystem7,
			rlSystem6Usable,
			rlSystemTooEarly
		}
	}}
};


	// Test for chosen volume being bootable.
	
resource 'inrl' ( rlBootableVolume )
{
	format0
	{{
		checkFileRsrcForkExists{ fsTargetSystem },					// does the system file exist
		checkFileRsrcForkExists{ fsTargetFinder },					// does the finder exist
		addAssertion{{ aBootableVolume }}
	}}
};


	// If volume is not bootable, come here to set assertion.
	
resource 'inrl' ( rlNoSystem )
{
	format0
	{{
		addAssertion{{ aNoSystem }}
	}}
};


	// Check whether chosen volume has System 7.0 or later.
	
resource 'inrl' ( rlSystem7 )
{
	format0
	{{
		checkAllAssertions{{ aBootableVolume }},
		checkFileVersion{ fsTargetSystem, 0x7, 0x00, release, 0x0 }, //	7.0.0 or later
		addAssertion{{ aSystem7 }},
	}}
};


	// If not System 7 or later, then come here and see if the chosen volume has
	// a version of System 6 that speech runs on.
	
resource 'inrl' ( rlSystem6Usable )
{
	format0
	{{
		checkAllAssertions{{ aBootableVolume }},
		checkFileVersion{ fsTargetSystem, 0x6, 0x07, release, 0x0 }, //	6.0.7 or later
		addAssertion{{ aSystem6Usable }},
	}}
};


	// If neither System 7 nor a speech-usable version of System 6, see if there's a
	// System that's just too old for speech.
	
resource 'inrl' ( rlSystemTooEarly )
{
	format0
	{{
		checkAllAssertions{{ aBootableVolume }},
		addAssertion{{ aSystemTooEarly }}
	}}
};


/************************** Rule resources for Easy Install **********************************/
// Rule framework.

resource 'infr' ( kEasyInstallFrameworkRsrcID )
{ 
	format0
	{{
				// Easy Install requires a bootable hard disk with a speech-capable
				// system to install on.
				
			pickFirst,
			{
				rlCheckUsableSystem,
				rlSystemVersionError,
				rlBootDiskError
			},
				
				
				// Choose the correct packages.  If we get here, we won't fail.
				
			pickFirst,
			{
				rlCheck_Sys607,						// If System 6, processor is unimportant.
				rlCheck_PPC,						// For Power Macs.
				rlCheck_040,						// For 68040 Macs.
				rlCheck_Fast030,					// For 33MHz or faster 68030 Macs.
				rlOther_Sys7						// Any other setup comes here.
			}
	}}
};

//------------------------------
// Test for a bootable hard disk with a speech-capable System.

resource 'inrl' ( rlCheckUsableSystem )
{
	format0
	{{
		checkTgtVolSize{ hardDisk, hardDisk },
		checkAllAssertions{{ aBootableVolume }},
		checkAnyAssertion{{ aSystem6Usable, aSystem7 }}
	}}
};

//------------------------------
// Not speech capable system.  If the disk can be booted, report that chosen volume does
// not have a speech-capable System.
// This prevents Easy Install from installing.

resource 'inrl' ( rlSystemVersionError )
{
	format0
	{{
		checkAllAssertions{{ aBootableVolume }},
		reportVolError
		{
			"Text-to-Speech requires System Software 6.0.7 or later."
			"  Please click Switch Disk to choose another disk."
		}
	}}
};

//------------------------------
// Report that chosen volume is not a bootable hard disk.
// This prevents Easy Install from installing.

resource 'inrl' ( rlBootDiskError )
{
	format0
	{{
		reportVolError
		{
			"Text-to-Speech must be installed on a hard disk with system software on it."
			"  Please click Switch Disk to choose another disk."
		}
	}}
};

//------------------------------
// System 6 on any Mac.

resource 'inrl' (rlCheck_Sys607) {
	format0 {{
		checkAllAssertions{{ aSystem6Usable }},
		addUserDescription {" MacinTalk 2 Software\n"},			//	message to appear in Easy Install screen
		addPackages {{pkRemoveMacinTalkPro}},
		addPackages {{pkRemoveMacinTalk3}},
		addPackages {{pkInstallMacinTalk2_607}}
	}}
};

//------------------------------
// Power Mac.

resource 'inrl' (rlCheck_PPC) {
	format0 {{
		checkGestalt {'sysa', { 2 } },								//	I am a PowerMac
		addUserDescription {" MacinTalk 3 Software\n"},			//	message to appear in Easy Install screen
		addUserDescription {" MacinTalk Pro Software\n"},			//	message to appear in Easy Install screen
		addPackages {{pkRemoveMacinTalk2}},
		addPackages {{pkInstallMacinTalk3}},
		addPackages {{pkInstallMacinTalkPro}},
	}}
};

//------------------------------
// 68040 Mac.

resource 'inrl' (rlCheck_040) {
	format0 {{
		checkGestalt {'proc',{5}},									//	processor is a 68040
		addUserDescription {" MacinTalk 3 Software\n"},			//	message to appear in Easy Install screen
		addUserDescription {" MacinTalk Pro Software\n"},			//	message to appear in Easy Install screen
		addPackages {{pkRemoveMacinTalk2}},
		addPackages {{pkInstallMacinTalk3}},
		addPackages {{pkInstallMacinTalkPro}},
	}}
};

//------------------------------
// 33MHz or faster 68030 Mac.

resource 'inrl' (rlCheck_Fast030) {
	format0 {{
		checkGestalt {'proc',{4}},									//	processor is a 68030
		checkUserFunction {UserFunctionType, chkGr33MHz, 0x0},		//	Check If machine is not slower then 33 MHz
		addUserDescription {" MacinTalk 3 Software\n"},			//	message to appear in Easy Install screen
		addPackages {{pkRemoveMacinTalk2}},
		addPackages {{pkRemoveMacinTalkPro}},
		addPackages {{pkInstallMacinTalk3}},
	}}
};

//------------------------------
// System 7 on a slow machine.

resource 'inrl' (rlOther_Sys7) {
	format0 {{
		addUserDescription {" MacinTalk 2 Software\n"},			//	message to appear in Easy Install screen
		addPackages {{pkRemoveMacinTalkPro}},
		addPackages {{pkRemoveMacinTalk3}},
		addPackages {{pkInstallMacinTalk2}}
	}}
};


/************************** Rule resources for Custom Install ********************************/
// Rule framework.

resource 'infr' ( kCustomInstallFrameworkRsrcID )
{ 
	format0
	{{
				// Which packages are available depends on the system version.
				
			pickFirst,
			{
				rlCustomCheck607,
				rlCustomCheckSys7,
				rlCustomSystemVersionError
			}
	}}
};

//------------------------------
// Under System 6, only MacinTalk 2 can be installed.

resource 'inrl' ( rlCustomCheck607 )
{
	format0
	{{
		checkAllAssertions{{ aSystem6Usable }},
		addCustomItems
		{{
			pkInstallMacinTalk2_607,
			pkInstallSpeechMgr607Custom
		}}
	}}
};

//------------------------------
// Under System 7, all synthesizers are possible.

resource 'inrl' ( rlCustomCheckSys7 )
{
	format0
	{{
		checkAllAssertions{{ aSystem7 }},
		addCustomItems
		{{
			pkInstallEnglishTTS,
			pkInstallMacinTalk2,
			pkInstallMacinTalk3,
			pkInstallMacinTalkPro,
			pkInstallSpeechMgrCustom
		}}
	}}
};

//------------------------------
// Report that chosen volume does not have a speech-capable System.
// This prevents Custom Install from installing.

resource 'inrl' ( rlCustomSystemVersionError )
{
	format0
	{{
		reportVolError
		{
			"Text-to-Speech requires System Software 6.0.7 or later."
			"  Please click Switch Disk to choose another disk."
		}
	}}
};


/***************************** Package Resources ************************************************/

resource 'inpk' (pkInstallEnglishTTS) {
	format0 {
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		removable,						// include package or subpackage as a removeable item
		forceRestart,					// make user reboot his computer after install
		cmtIEnglishTTS,		 			// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"All English Text-to-Speech Software", 	// Custom Install selection text
		{	
			'inpk', pkInstallMacinTalk2;	//	Installs MacinTalk 2 package
			'inpk', pkInstallMacinTalk3;	//	Installs MacinTalk 3 package
			'inpk', pkInstallMacinTalkPro;	//	Installs MacinTalk Pro package
		}
	}
};

//------------------------------
// Install MacinTalk 2 files that work with both System 6 and System 7

resource 'inpk' (pkInstallMacinTalk2_607) {
	format0 {
		doesntShowOnCustom, 			// Can't have ShowOnCustom; used as a sub-package.
		removable,						// include package or subpackage as a removeable item
		forceRestart,					// make user reboot his computer after install
		cmtIMacinTalk2,		 			// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"MacinTalk 2 Software",		 	// Custom Install selection text
		{	
			'inpk', pkRemoveOldMacinTalk2;					// Remove old versions of MacinTalk 2.

			'infa', sourceFileBase + 1;						//	Install "Using English Text-to-Speech"
			'infa', sourceFileBase + fMT2ExtFolder;			//	Install "MacinTalk 2"

			'infa', sourceFileBase + fSpeechMgrNoRemove;	//	Install "Speech Manager"
			'inra', sourceFileBase + 100;	//	Install Resource "MacinTalk 2 ttsp"	(Extensions:Speech Manager)

			'infa', sourceFileBase + 50;	//	Install "Ben"		(Extensions:Voices:)
			'infa', sourceFileBase + 51;	//	Install "Boris"		(Extensions:Voices:)
			'infa', sourceFileBase + 52;	//	Install "Brenda"	(Extensions:Voices:)
			'infa', sourceFileBase + 53;	//	Install "Mariel"	(Extensions:Voices:)
			'infa', sourceFileBase + 54;	//	Install "Marvin"	(Extensions:Voices:)
			'infa', sourceFileBase + 55;	//	Install "Mr. Hughes"(Extensions:Voices:)
			'infa', sourceFileBase + 56;	//	Install "Otis"		(Extensions:Voices:)
			'infa', sourceFileBase + 57;	//	Install "RoboVox"	(Extensions:Voices:)
			'infa', sourceFileBase + 58;	//	Install "Votron"	(Extensions:Voices:)
			'infa', sourceFileBase + 59;	//	Install "Xero"		(Extensions:Voices:)
		}
	}
};

//------------------------------
// Install MacinTalk 2 for System 7 only.

resource 'inpk' (pkInstallMacinTalk2) {
	format0 {
		doesntShowOnCustom, 			// Can't have ShowOnCustom; used as a sub-package.
		removable,						// include package or subpackage as a removeable item
		forceRestart,					// make user reboot his computer after install
		cmtIMacinTalk2,		 			// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"MacinTalk 2 Software", 		// Custom Install selection text
		{	
				// Remove MacinTalk 2 files in alternative locations.  Only for System 7,
				// since this would remove possibly newer files in the correct locations
				// under System 6.
			'inpk', pkRemoveMisplacedMacinTalk2;

			'inpk', pkInstallMacinTalk2_607;	//	Install the 6.0.7 MacinTalk 2 package

			'infa', sourceFileBase + 2;		//	Install "SimpleText"
			'infa', sourceFileBase + fSpeechCDevNoRemove;		//	Install "Speech"
		}
	}
};

//------------------------------
// Install MacinTalk 3.

resource 'inpk' (pkInstallMacinTalk3) {
	format0 {
		doesntShowOnCustom, 			// Can't have ShowOnCustom; used as a sub-package.
		removable,						// include package or subpackage as a removeable item
		forceRestart,					// make user reboot his computer after install
		cmtIMacinTalk3,		 			// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"MacinTalk 3 Software", 		// Custom Install selection text
		{	
			'inpk', pkRemoveMisplacedMacinTalk3;	// Remove files from non-canonical locations.

			'infa', sourceFileBase + 1;		//	Install "Using English Text-to-Speech"
			'infa', sourceFileBase + 2;		//	Install "SimpleText"
			'infa', sourceFileBase + fSpeechCDevNoRemove;	//	Install "Speech"
			'infa', sourceFileBase + 6;		//	Install "MacinTalk 3"

			'infa', sourceFileBase + fSpeechMgrNoRemove;	//	Install "Speech Manager"
			'inra', sourceFileBase + 101;	//	Install Resource "MacinTalk 3 ttsp"	(Extensions:Speech Manager)

			'infa', sourceFileBase + 60;	//	Install "Albert"	(Extensions:Voices:)
			'infa', sourceFileBase + 61;	//	Install "Bad News"	(Extensions:Voices:)
			'infa', sourceFileBase + 62;	//	Install "Bahh"		(Extensions:Voices:)
			'infa', sourceFileBase + 63;	//	Install "Bells"		(Extensions:Voices:)
			'infa', sourceFileBase + 64;	//	Install "Boing"		(Extensions:Voices:)
			'infa', sourceFileBase + 65;	//	Install "Bubbles"	(Extensions:Voices:)
			'infa', sourceFileBase + 66;	//	Install "Cellos"	(Extensions:Voices:)
			'infa', sourceFileBase + 67;	//	Install "Deranged"	(Extensions:Voices:)
			'infa', sourceFileBase + 68;	//	Install "Fred"		(Extensions:Voices:)
			'infa', sourceFileBase + 69;	//	Install "Good News"	(Extensions:Voices:)
			'infa', sourceFileBase + 70;	//	Install "Hysterical"(Extensions:Voices:)
			'infa', sourceFileBase + 71;	//	Install "Junior"	(Extensions:Voices:)
			'infa', sourceFileBase + 72;	//	Install "Kathy"		(Extensions:Voices:)
			'infa', sourceFileBase + 73;	//	Install "Pipe Organ"(Extensions:Voices:)
			'infa', sourceFileBase + 74;	//	Install "Princess"	(Extensions:Voices:)
			'infa', sourceFileBase + 75;	//	Install "Ralph"		(Extensions:Voices:)
			'infa', sourceFileBase + 76;	//	Install "Trinoids"	(Extensions:Voices:)
			'infa', sourceFileBase + 77;	//	Install "Whisper"	(Extensions:Voices:)
			'infa', sourceFileBase + 78;	//	Install "Zarvox"	(Extensions:Voices:)
		}
	}
};

//------------------------------
// Install MacinTalk Pro.

resource 'inpk' (pkInstallMacinTalkPro) {
	format0 {
		doesntShowOnCustom, 			// Can't have ShowOnCustom; used as a sub-package.
		removable,						// include package or subpackage as a removeable item
		forceRestart,					// make user reboot his computer after install
		cmtIMacinTalkPro,		 		// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"MacinTalk Pro Software", 		// Custom Install selection text
		{
			'inpk', pkRemoveMisplacedMacinTalkPro;	// Remove files from non-canonical locations.
			'inpk', pkRemoveOldMacinTalkPro;		// Remove old versions of MacinTalk Pro.


			'infa', sourceFileBase + fSpeechCDevNoRemove;	//	Install "Speech"
			'infa', sourceFileBase + fSpeechMgrNoRemove;	//	Install "Speech Manager"
			'infa', sourceFileBase + 1;		//	Install "Using English Text-to-Speech"
			'infa', sourceFileBase + 2;		//	Install "SimpleText"
			'infa', sourceFileBase + 7;		//	Install "MacinTalk Pro"
			'infa', sourceFileBase + 80;	//	Install "Agnes"		(Extensions:Voices:)
			'infa', sourceFileBase + 81;	//	Install "Bruce"		(Extensions:Voices:)
			'infa', sourceFileBase + 82;	//	Install "Victoria"	(Extensions:Voices:)
		}
	}
};


//============================================================
// The Speech Manager packages for Custom Install/Remove.

//------------------------------
// Speech Manager for System 7 or later, i.e. can install cdev.

resource 'inpk' (pkInstallSpeechMgrCustom)
{
	format0
	{
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		removable,						// include package or subpackage as a removeable item
		forceRestart,					// make user reboot his computer after install
		cmtISpeechMgr,		 			// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"Speech Manager Software", 		// Custom Install selection text
		{	
			'inpk', pkInstallSpeechMgrExtCustom;// Installs Package "Speech Manager Extension"
			'inpk', pkInstallSpeechCDevCustom;// Installs Package "Speech Control Panel"
		}
	}
};

//------------------------------
// Sub-package for Speech Manager, System 7.  Allow user to install just the extension.

resource 'inpk' (pkInstallSpeechMgrExtCustom)
{
	format0
	{
		showsOnCustom, 					// if a subpackage, then show in Custom Install
		removable,						// include package or subpackage as a removeable item
		forceRestart,					// make user reboot his computer after install
		cmtISpeechMgrExt,		 		// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"Speech Manager Extension", 	// Custom Install selection text
		{	
			'infa', sourceFileBase + fSpeechMgr;		//	Install "Speech Manager"
		}
	}
};

//------------------------------
// Sub-package for Speech Manager, System 7.  Allow user to install just the cdev.

resource 'inpk' (pkInstallSpeechCDevCustom)
{
	format0
	{
		showsOnCustom, 					// if a subpackage, then show in Custom Install
		removable,						// include package or subpackage as a removeable item
		forceRestart,					// make user reboot his computer after install
		cmtISpeechCDev,		 			// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"Speech Control Panel", 		// Custom Install selection text
		{	
			'infa', sourceFileBase + fSpeechCDev;		//	Install "Speech"
		}
	}
};

//------------------------------
// Speech Manager for System 6; no cdev.

resource 'inpk' (pkInstallSpeechMgr607Custom)
{
	format0
	{
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		removable,						// include package or subpackage as a removeable item
		forceRestart,					// make user reboot his computer after install
		cmtISpeechMgr,		 			// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"Speech Manager Software", 		// Custom Install selection text
		{	
			'infa', sourceFileBase + fSpeechMgr;		//	Install "Speech Manager"
		}
	}
};


//============================================================
// Removal packages

//------------------------------
// Remove previous versions of MacinTalk 2.

resource 'inpk' ( pkRemoveOldMacinTalk2 )
{
	format0
	{
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		notRemovable,					// include package or subpackage as a removeable item
		dontForceRestart,				// make user reboot his computer after install
		0,		 						// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"", 							// Custom Install selection text
		{	
			'infa', sourceFileBase + 201;						//	Delete "MacinTalk Voices"	(Extensions:)
			'infa', sourceFileBase + 202;						//	Delete "MacinTalk Voices"	(Extensions:Voices:)
			'infa', sourceFileBase + fDelOldMTVoicesSysFolder;	//	Delete "MacinTalk Voices"	(System Folder:)

			'infa', sourceFileBase + 203;						//	Delete "MacinTalk2 Voices"	(Extensions:)
			'infa', sourceFileBase + 204;						//	Delete "MacinTalk2 Voices"	(Extensions:Voices:)
			'infa', sourceFileBase + fDelOldMT2VoicesSysFolder;	//	Delete "MacinTalk2 Voices"	(System Folder:)
		}
	}
};

//------------------------------
// Remove current MacinTalk 2 files that are not in the canonical location.
// Only use this with System 7 or greater; under System 6 this can remove
// files that are in the right location.

resource 'inpk' ( pkRemoveMisplacedMacinTalk2 )
{
	format0
	{
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		notRemovable,					// include package or subpackage as a removeable item
		dontForceRestart,				// make user reboot his computer after install
		0,		 						// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"", 							// Custom Install selection text
		{	
			'infa', sourceFileBase + fDelMT2SysFolder;			//	Delete "MacinTalk 2" (System Folder:)
			
			'infa', sourceFileBase + 350;	//	Delete "Ben"		(Extensions:)
			'infa', sourceFileBase + 352;	//	Delete "Boris"		(Extensions:)
			'infa', sourceFileBase + 354;	//	Delete "Brenda"		(Extensions:)
			'infa', sourceFileBase + 356;	//	Delete "Mariel"		(Extensions:)
			'infa', sourceFileBase + 358;	//	Delete "Marvin"		(Extensions:)
			'infa', sourceFileBase + 360;	//	Delete "Mr. Hughes"	(Extensions:)
			'infa', sourceFileBase + 362;	//	Delete "Otis"		(Extensions:)
			'infa', sourceFileBase + 364;	//	Delete "RoboVox"	(Extensions:)
			'infa', sourceFileBase + 366;	//	Delete "Votron"		(Extensions:)
			'infa', sourceFileBase + 368;	//	Delete "Xero"		(Extensions:)
		}
	}
};

//------------------------------
// Remove MacinTalk 2 completely.  Used by Easy Install, NOT Custom Remove.

resource 'inpk' ( pkRemoveMacinTalk2 )
{
	format0
	{
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		notRemovable,					// include package or subpackage as a removeable item
		dontForceRestart,				// make user reboot his computer after install
		0,		 						// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"", 							// Custom Install selection text
		{	
			'inpk', pkRemoveOldMacinTalk2;				// Remove old versions of MacinTalk 2.
			'inpk', pkRemoveMisplacedMacinTalk2;		// Remove MacinTalk 2 files in alternative locations.
			
				// Remove MacinTalk 2 files from their normal locations.
			'infa', sourceFileBase + fDelMT2ExtFolder;	//	Delete "MacinTalk 2"	(Extensions:)
			'infa', sourceFileBase + 351;				//	Delete "Ben"		(Extensions:Voices:)
			'infa', sourceFileBase + 353;				//	Delete "Boris"		(Extensions:Voices:)
			'infa', sourceFileBase + 355;				//	Delete "Brenda"		(Extensions:Voices:)
			'infa', sourceFileBase + 357;				//	Delete "Mariel"		(Extensions:Voices:)
			'infa', sourceFileBase + 359;				//	Delete "Marvin"		(Extensions:Voices:)
			'infa', sourceFileBase + 361;				//	Delete "Mr. Hughes"	(Extensions:Voices:)
			'infa', sourceFileBase + 363;				//	Delete "Otis"		(Extensions:Voices:)
			'infa', sourceFileBase + 365;				//	Delete "RoboVox"	(Extensions:Voices:)
			'infa', sourceFileBase + 367;				//	Delete "Votron"		(Extensions:Voices:)
			'infa', sourceFileBase + 369;				//	Delete "Xero"		(Extensions:Voices:)
		}
	}
};

//------------------------------
// Remove current MacinTalk 3 files that are not in the canonical location.

resource 'inpk' ( pkRemoveMisplacedMacinTalk3 )
{
	format0
	{
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		notRemovable,					// include package or subpackage as a removeable item
		dontForceRestart,				// make user reboot his computer after install
		0,		 						// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"", 							// Custom Install selection text
		{	
			'infa', sourceFileBase + fDelMT3SysFolder;			//	Delete "MacinTalk 3" (System Folder:)
			
			'infa', sourceFileBase + 250;	//	Delete "Albert"		(Extensions:)
			'infa', sourceFileBase + 252;	//	Delete "Bad News"	(Extensions:)
			'infa', sourceFileBase + 254;	//	Delete "Bahh"		(Extensions:)
			'infa', sourceFileBase + 256;	//	Delete "Bells"		(Extensions:)
			'infa', sourceFileBase + 258;	//	Delete "Boing"		(Extensions:)
			'infa', sourceFileBase + 260;	//	Delete "Bubbles"	(Extensions:)
			'infa', sourceFileBase + 262;	//	Delete "Cellos"		(Extensions:)
			'infa', sourceFileBase + 264;	//	Delete "Deranged"	(Extensions:)
			'infa', sourceFileBase + 266;	//	Delete "Fred"		(Extensions:)
			'infa', sourceFileBase + 268;	//	Delete "Good News"	(Extensions:)
			'infa', sourceFileBase + 270;	//	Delete "Hysterical"	(Extensions:)
			'infa', sourceFileBase + 272;	//	Delete "Junior"		(Extensions:)
			'infa', sourceFileBase + 274;	//	Delete "Kathy"		(Extensions:)
			'infa', sourceFileBase + 276;	//	Delete "Pipe Organ"	(Extensions:)
			'infa', sourceFileBase + 278;	//	Delete "Princess"	(Extensions:)
			'infa', sourceFileBase + 280;	//	Delete "Ralph"		(Extensions:)
			'infa', sourceFileBase + 282;	//	Delete "Trinoids"	(Extensions:)
			'infa', sourceFileBase + 284;	//	Delete "Whisper"	(Extensions:)
			'infa', sourceFileBase + 286;	//	Delete "Zarvox"		(Extensions:)
		}
	}
};

//------------------------------
// Remove MacinTalk 3 completely.  Used by Easy Install, NOT Custom Remove.

resource 'inpk' ( pkRemoveMacinTalk3 )
{
	format0
	{
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		notRemovable,					// include package or subpackage as a removeable item
		dontForceRestart,				// make user reboot his computer after install
		0,		 						// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"", 							// Custom Install selection text
		{	
			'inpk', pkRemoveMisplacedMacinTalk3;		// Remove MacinTalk 3 files in alternative locations.
			
				// Remove MacinTalk 3 files from their normal locations.
			'infa', sourceFileBase + 207;	//	Delete "MacinTalk 3"(Extensions:)
			'infa', sourceFileBase + 251;	//	Delete "Albert"		(Extensions:Voices:)
			'infa', sourceFileBase + 253;	//	Delete "Bad News"	(Extensions:Voices:)
			'infa', sourceFileBase + 255;	//	Delete "Bahh"		(Extensions:Voices:)
			'infa', sourceFileBase + 257;	//	Delete "Bells"		(Extensions:Voices:)
			'infa', sourceFileBase + 259;	//	Delete "Boing"		(Extensions:Voices:)
			'infa', sourceFileBase + 261;	//	Delete "Bubbles"	(Extensions:Voices:)
			'infa', sourceFileBase + 263;	//	Delete "Cellos"		(Extensions:Voices:)
			'infa', sourceFileBase + 265;	//	Delete "Deranged"	(Extensions:Voices:)
			'infa', sourceFileBase + 267;	//	Delete "Fred"		(Extensions:Voices:)
			'infa', sourceFileBase + 269;	//	Delete "Good News"	(Extensions:Voices:)
			'infa', sourceFileBase + 271;	//	Delete "Hysterical"	(Extensions:Voices:)
			'infa', sourceFileBase + 273;	//	Delete "Junior"		(Extensions:Voices:)
			'infa', sourceFileBase + 275;	//	Delete "Kathy"		(Extensions:Voices:)
			'infa', sourceFileBase + 277;	//	Delete "Pipe Organ"	(Extensions:Voices:)
			'infa', sourceFileBase + 279;	//	Delete "Princess"	(Extensions:Voices:)
			'infa', sourceFileBase + 281;	//	Delete "Ralph"		(Extensions:Voices:)
			'infa', sourceFileBase + 283;	//	Delete "Trinoids"	(Extensions:Voices:)
			'infa', sourceFileBase + 285;	//	Delete "Whisper"	(Extensions:Voices:)
			'infa', sourceFileBase + 287;	//	Delete "Zarvox"		(Extensions:Voices:)
		}
	}
};

//------------------------------
// Remove previous versions of MacinTalk Pro.

resource 'inpk' ( pkRemoveOldMacinTalkPro )
{
	format0
	{
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		notRemovable,					// include package or subpackage as a removeable item
		dontForceRestart,				// make user reboot his computer after install
		0,		 						// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"", 							// Custom Install selection text
		{	
			'infa', sourceFileBase + 205;	//	Delete "PlainTalk Text-to-Speech"	(Extensions:)
			'infa', sourceFileBase + 206;	//	Delete "MacinTalkPro 2"				(Extensions:)

			'infa', sourceFileBase + 290;	//	Delete "TTS Female Voice"			(Extensions:)
			'infa', sourceFileBase + 291;	//	Delete "TTS Female Voice"			(Extensions:Voices:)
			'infa', sourceFileBase + 292;	//	Delete "TTS Male Voice"				(Extensions:)
			'infa', sourceFileBase + 293;	//	Delete "TTS Male Voice"				(Extensions:Voices:)
			'infa', sourceFileBase + 294;	//	Delete "TTS Male Voice, Compressed"	(Extensions:)
			'infa', sourceFileBase + 295;	//	Delete "TTS Male Voice, Compressed"	(Extensions:Voices:)
			'infa', sourceFileBase + 296;	//	Delete "TTS Victoria"				(Extensions:)
			'infa', sourceFileBase + 297;	//	Delete "TTS Victoria"				(Extensions:Voices:)
			'infa', sourceFileBase + 298;	//	Delete "TTS Agnes"					(Extensions:)
			'infa', sourceFileBase + 299;	//	Delete "TTS Agnes"					(Extensions:Voices:)
			'infa', sourceFileBase + 300;	//	Delete "TTS Bruce"					(Extensions:)
			'infa', sourceFileBase + 301;	//	Delete "TTS Bruce"					(Extensions:Voices:)
		}
	}
};

//------------------------------
// Remove current MacinTalk Pro files that are not in the canonical location.

resource 'inpk' ( pkRemoveMisplacedMacinTalkPro )
{
	format0
	{
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		notRemovable,					// include package or subpackage as a removeable item
		dontForceRestart,				// make user reboot his computer after install
		0,		 						// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"", 							// Custom Install selection text
		{	
			'infa', sourceFileBase + fDelMTPSysFolder;			//	Delete "MacinTalk Pro" (System Folder:)

			'infa', sourceFileBase + 314;	//	Delete "Agnes"						(Extensions:)
			'infa', sourceFileBase + 316;	//	Delete "Bruce"						(Extensions:)
			'infa', sourceFileBase + 318;	//	Delete "Victoria"					(Extensions:)
		}
	}
};

//------------------------------
// Remove MacinTalk Pro completely.  Used by Easy Install, NOT Custom Remove.

resource 'inpk' (pkRemoveMacinTalkPro) {
	format0 {
		doesntShowOnCustom, 			// if a subpackage, then show in Custom Install
		notRemovable,					// include package or subpackage as a removeable item
		dontForceRestart,				// make user reboot his computer after install
		0,		 						// ID of package comments ( 'inpc' ) rsrc defined below
		0,								// Package size ( if 0, filled in by ScriptCheck )
		"Remove MacinTalk Pro Software", 	// Custom Install selection text
		{	
			'inpk', pkRemoveOldMacinTalkPro;			// Remove old versions of MacinTalk Pro.
			'inpk', pkRemoveMisplacedMacinTalkPro;		// Remove MacinTalk Pro files in alternative locations.
			
				// Remove MacinTalk Pro files from their normal locations.
			'infa', sourceFileBase + 208;	//	Delete "MacinTalk Pro"				(Extensions:)
			'infa', sourceFileBase + 315;	//	Delete "Agnes"						(Extensions:Voices:)
			'infa', sourceFileBase + 317;	//	Delete "Bruce"						(Extensions:Voices:)
			'infa', sourceFileBase + 319;	//	Delete "Victoria"					(Extensions:Voices:)
		}
	}
};


/***************************** Comments ************************************************/
// NOTE: ignore the warning from ScriptCheck about these comments not being needed
// because the packages have doesntShowOnCustom set.  The custom rules install the
// packages and then the comments are available.

resource 'icmt' (cmtIEnglishTTS) {
	currentReleaseDate,
	kTTSVersionIcmt,
	iconEnglishTTS,
	"This package contains all of Apple's software that's used to have English text spoken aloud."
	"  This includes the MacinTalk 2, MacinTalk 3, and MacinTalk Pro text-to-speech synthesizers."
};

resource 'icmt' (cmtIMacinTalk2) {
	currentReleaseDate,
	kTTSVersionIcmt,
	iconMacinTalk2,
	"This package contains the MacinTalk 2 software, best for less powerful Macintoshes"
	" and on Macintoshes running System Software 6.0.7 or later."
};

resource 'icmt' (cmtIMacinTalk3) {
	currentReleaseDate,
	kTTSVersionIcmt,
	iconMacinTalk3,
	"This package contains the MacinTalk 3 software, useful under System 7,"
	" on Macintoshes with a 68030 processor of at least 33MHz,"
	" or any Macintosh with a 68040 or PowerPC processor."
};

resource 'icmt' (cmtIMacinTalkPro) {
	currentReleaseDate,
	kTTSVersionIcmt,
	iconMacinTalkPro,
	"This package contains the MacinTalk Pro software, useful under System 7,"
	" on Macintoshes with a 68040 or PowerPC processor."
};

resource 'icmt' (cmtISpeechMgr) {
	currentReleaseDate,
	kTTSVersionIcmt,
	iconSpeechMgr,
	"This package contains the Speech Manager software, used by all text-to-speech synthesizers."
};

resource 'icmt' (cmtISpeechMgrExt) {
	currentReleaseDate,
	kTTSVersionIcmt,
	iconSpeechMgr,
	"This package contains the Speech Manager Extension,"
	" required for text-to-speech."
};

resource 'icmt' (cmtISpeechCDev) {
	currentReleaseDate,
	kTTSVersionIcmt,
	iconSpeechCDev,
	"This package contains the Speech Control Panel,"
	" used to select options for text-to-speech."
};



/***************************** Special File Specs *************************************/

resource 'intf' (fsTargetSystem) 	/* File Spec */
{
	format0
	{
		noSearchForFile,
		TypeCrNeedNotMatch,			// Type is 'ZSYS' for 6.0.7, 'zsys' for 7.0.
		'zsys',
		'MACS',
		0x0,
		"special-macs:System"
	}
};

resource 'infs' (fsTargetFinder) { 	/* File Spec */
	'FNDR',
	'MACS',
	0x0,
	noSearchForFile,
	TypeCrMustMatch,
	"special-macs:Finder"
};


/***************************** All Other File Specs *************************************/
#include	"InstallFiles_TTS14.r"
